Class: Mappum::Map

Inherits:
Object show all
Defined in:
lib/mappum/map.rb

Overview

Base Map class representing mapping betwean two or more types, properties etc.

Direct Known Subclasses

FieldMap, RootMap

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeMap

Returns a new instance of Map.



7
8
9
10
11
# File 'lib/mappum/map.rb', line 7

def initialize
  @maps = []
  @bidi_maps =[]
  @strip_empty = true
end

Instance Attribute Details

#bidi_mapsObject

Returns the value of attribute bidi_maps.



5
6
7
# File 'lib/mappum/map.rb', line 5

def bidi_maps
  @bidi_maps
end

#mapsObject

Returns the value of attribute maps.



5
6
7
# File 'lib/mappum/map.rb', line 5

def maps
  @maps
end

#sourceObject

Returns the value of attribute source.



5
6
7
# File 'lib/mappum/map.rb', line 5

def source
  @source
end

#src_refObject

Returns the value of attribute src_ref.



5
6
7
# File 'lib/mappum/map.rb', line 5

def src_ref
  @src_ref
end

#strip_emptyObject

Returns the value of attribute strip_empty.



5
6
7
# File 'lib/mappum/map.rb', line 5

def strip_empty
  @strip_empty
end

Instance Method Details

#strip_empty?Boolean

When value of mapped property is null remove property.

Returns:

  • (Boolean)


13
14
15
# File 'lib/mappum/map.rb', line 13

def strip_empty?
  @strip_empty
end