Class: Mappum::Map
Overview
Base Map class representing mapping betwean two or more types, properties etc.
Instance Attribute Summary collapse
-
#bidi_maps ⇒ Object
Returns the value of attribute bidi_maps.
-
#maps ⇒ Object
Returns the value of attribute maps.
-
#source ⇒ Object
Returns the value of attribute source.
-
#src_ref ⇒ Object
Returns the value of attribute src_ref.
-
#strip_empty ⇒ Object
Returns the value of attribute strip_empty.
Instance Method Summary collapse
-
#initialize ⇒ Map
constructor
A new instance of Map.
-
#strip_empty? ⇒ Boolean
When value of mapped property is null remove property.
Constructor Details
#initialize ⇒ Map
Returns a new instance of Map.
7 8 9 10 11 |
# File 'lib/mappum/map.rb', line 7 def initialize @maps = [] @bidi_maps =[] @strip_empty = true end |
Instance Attribute Details
#bidi_maps ⇒ Object
Returns the value of attribute bidi_maps.
5 6 7 |
# File 'lib/mappum/map.rb', line 5 def bidi_maps @bidi_maps end |
#maps ⇒ Object
Returns the value of attribute maps.
5 6 7 |
# File 'lib/mappum/map.rb', line 5 def maps @maps end |
#source ⇒ Object
Returns the value of attribute source.
5 6 7 |
# File 'lib/mappum/map.rb', line 5 def source @source end |
#src_ref ⇒ Object
Returns the value of attribute src_ref.
5 6 7 |
# File 'lib/mappum/map.rb', line 5 def src_ref @src_ref end |
#strip_empty ⇒ Object
Returns the value of attribute strip_empty.
5 6 7 |
# File 'lib/mappum/map.rb', line 5 def strip_empty @strip_empty end |
Instance Method Details
#strip_empty? ⇒ Boolean
When value of mapped property is null remove property.
13 14 15 |
# File 'lib/mappum/map.rb', line 13 def strip_empty? @strip_empty end |